searchData={"items":[{"type":"module","title":"Testcontainers.Connection","doc":"This module provides an abstraction for interacting with Docker containers.\n\nIt manages the lifecycle of Docker containers, including creating, starting, and stopping instances, as well as executing commands within running containers. Communication with the Docker daemon is handled through a GenServer, which maintains the state of the connection and executes commands asynchronously.","ref":"Testcontainers.Connection.html"},{"type":"module","title":"Examples - Testcontainers.Connection","doc":"The following examples demonstrate basic usage:\n\n    # Start a new container\n    {:ok, container} = Testcontainers.Connection.start_container(\"my_container_id\")\n\n    # Execute a command within a running container\n    result = Testcontainers.Connection.exec_create(\"my_container_id\", [\"ls\"])","ref":"Testcontainers.Connection.html#module-examples"},{"type":"module","title":"Notes - Testcontainers.Connection","doc":"- This module should be used as a singleton. It is started with the application and should not be manually restarted.\n- All interaction with containers should go through this module to ensure proper connection management and error handling.","ref":"Testcontainers.Connection.html#module-notes"},{"type":"function","title":"Testcontainers.Connection.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Testcontainers.Connection.html#child_spec/1"},{"type":"function","title":"Testcontainers.Connection.create_container/1","doc":"Creates a Docker container based on the specified configuration.\n\nThe container is not started automatically. Use `start_container/1` to run it.","ref":"Testcontainers.Connection.html#create_container/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.create_container/1","doc":"- `container`: A `%Container{}` struct containing the configuration for the new Docker container.","ref":"Testcontainers.Connection.html#create_container/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.create_container/1","doc":"- `{:ok, container_id}` if the container is successfully created.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#create_container/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.create_container/1","doc":"config = %Container{image: \"nginx:latest\"}\n    {:ok, container_id} = Testcontainers.Connection.create_container(config)","ref":"Testcontainers.Connection.html#create_container/1-examples"},{"type":"function","title":"Testcontainers.Connection.exec_create/2","doc":"Creates a new execution context in a running container and runs the specified command.\n\nThis function is used to execute a one-off command within the context of the container.","ref":"Testcontainers.Connection.html#exec_create/2"},{"type":"function","title":"Parameters - Testcontainers.Connection.exec_create/2","doc":"- `container_id`: The ID of the container, as a string.\n- `command`: A list of strings representing the command and its arguments to run in the container.","ref":"Testcontainers.Connection.html#exec_create/2-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.exec_create/2","doc":"- `{:ok, exec_id}` which is an identifier for the executed command, useful for further inspection or interaction.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#exec_create/2-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.exec_create/2","doc":"{:ok, exec_id} = Testcontainers.Connection.exec_create(\"my_container_id\", [\"ls\", \"-la\"])","ref":"Testcontainers.Connection.html#exec_create/2-examples"},{"type":"function","title":"Testcontainers.Connection.exec_inspect/1","doc":"Retrieves detailed information about a specific exec command.\n\nIt's particularly useful for obtaining the exit status and other related data after a command has been executed in a container.","ref":"Testcontainers.Connection.html#exec_inspect/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.exec_inspect/1","doc":"- `exec_id`: A string representing the unique identifier of the executed command (obtained from `exec_create/2`).","ref":"Testcontainers.Connection.html#exec_inspect/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.exec_inspect/1","doc":"- `{:ok, %{running: _, exit_code: _}}` with information about running state and exit code.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#exec_inspect/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.exec_inspect/1","doc":"{:ok, exec_info} = Testcontainers.Connection.exec_inspect(\"my_exec_id\")","ref":"Testcontainers.Connection.html#exec_inspect/1-examples"},{"type":"function","title":"Testcontainers.Connection.exec_start/1","doc":"Initiates the execution of a previously created command in a running container.\n\nThis function is used after `exec_create/2` to start the execution of the command within the container context.","ref":"Testcontainers.Connection.html#exec_start/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.exec_start/1","doc":"- `exec_id`: A string representing the unique identifier of the command to be executed (obtained from `exec_create/2`).","ref":"Testcontainers.Connection.html#exec_start/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.exec_start/1","doc":"- `:ok` if the command execution started successfully.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#exec_start/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.exec_start/1","doc":":ok = Testcontainers.Connection.exec_start(\"my_exec_id\")","ref":"Testcontainers.Connection.html#exec_start/1-examples"},{"type":"function","title":"Testcontainers.Connection.get_container/1","doc":"Retrieves information about a specific container.\n\nThis can be used to check the status, inspect the configuration, and gather other runtime information about the container.","ref":"Testcontainers.Connection.html#get_container/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.get_container/1","doc":"- `container_id`: The ID of the container, as a string.","ref":"Testcontainers.Connection.html#get_container/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.get_container/1","doc":"- `{:ok, %Testcontainers.Container{}}` with detailed information about the container.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#get_container/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.get_container/1","doc":"{:ok, %Testcontainers.Container{}} = Testcontainers.Connection.get_container(\"my_container_id\")","ref":"Testcontainers.Connection.html#get_container/1-examples"},{"type":"function","title":"Testcontainers.Connection.pull_image/1","doc":"Pulls a Docker image.\n\nThis function sends a request to the Docker daemon to pull an image from a Docker registry. If the image already exists locally, it will be skipped.","ref":"Testcontainers.Connection.html#pull_image/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.pull_image/1","doc":"- `image`: A string representing the Docker image tag.","ref":"Testcontainers.Connection.html#pull_image/1-parameters"},{"type":"function","title":"Examples - Testcontainers.Connection.pull_image/1","doc":":ok = Testcontainers.Connection.pull_image(\"nginx:latest\")","ref":"Testcontainers.Connection.html#pull_image/1-examples"},{"type":"function","title":"Returns - Testcontainers.Connection.pull_image/1","doc":"- `:ok` if the image is successfully pulled.\n- `{:error, reason}` if there is a failure to pull the image.","ref":"Testcontainers.Connection.html#pull_image/1-returns"},{"type":"function","title":"Notes - Testcontainers.Connection.pull_image/1","doc":"- This function requires that the Docker daemon is running and accessible.\n- Network issues or invalid image tags can cause failures.","ref":"Testcontainers.Connection.html#pull_image/1-notes"},{"type":"function","title":"Testcontainers.Connection.start_container/1","doc":"Starts a previously created Docker container.\n\nRequires the container ID of a container that has been created but not yet started.","ref":"Testcontainers.Connection.html#start_container/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.start_container/1","doc":"- `container_id`: The ID of the container to start, as a string.","ref":"Testcontainers.Connection.html#start_container/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.start_container/1","doc":"- `:ok` if the container starts successfully.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#start_container/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.start_container/1","doc":":ok = Testcontainers.Connection.start_container(\"my_container_id\")","ref":"Testcontainers.Connection.html#start_container/1-examples"},{"type":"function","title":"Testcontainers.Connection.start_eager/1","doc":"Starts the GenServer (if it's not already started), enabling the handling of Docker containers.\n\nThis function should typically be called at the start of your application to ensure the GenServer is running.","ref":"Testcontainers.Connection.html#start_eager/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.start_eager/1","doc":"- `options`: (Optional) A list of options. This can be empty as the defaults are usually sufficient.","ref":"Testcontainers.Connection.html#start_eager/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.start_eager/1","doc":"- `{:ok, pid}` on successful start.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#start_eager/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.start_eager/1","doc":"{:ok, pid} = Testcontainers.Connection.start_eager()","ref":"Testcontainers.Connection.html#start_eager/1-examples"},{"type":"function","title":"Testcontainers.Connection.stdout_logs/1","doc":"Retrieves the stdout logs from a specified container.\n\nUseful for debugging and monitoring, this function collects the logs that have been written to stdout within the container.","ref":"Testcontainers.Connection.html#stdout_logs/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.stdout_logs/1","doc":"- `container_id`: The ID of the container, as a string.","ref":"Testcontainers.Connection.html#stdout_logs/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.stdout_logs/1","doc":"- `{:ok, logs}` where `logs` is the content that has been written to stdout in the container.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#stdout_logs/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.stdout_logs/1","doc":"{:ok, logs} = Testcontainers.Connection.stdout_logs(\"my_container_id\")","ref":"Testcontainers.Connection.html#stdout_logs/1-examples"},{"type":"function","title":"Testcontainers.Connection.stop_container/1","doc":"Stops a running container.\n\nThis sends a stop command to the specified container. The Docker daemon terminates the container process gracefully.","ref":"Testcontainers.Connection.html#stop_container/1"},{"type":"function","title":"Parameters - Testcontainers.Connection.stop_container/1","doc":"- `container_id`: The ID of the container to stop, as a string.","ref":"Testcontainers.Connection.html#stop_container/1-parameters"},{"type":"function","title":"Returns - Testcontainers.Connection.stop_container/1","doc":"- `:ok` if the container stops successfully.\n- `{:error, reason}` on failure.","ref":"Testcontainers.Connection.html#stop_container/1-returns"},{"type":"function","title":"Examples - Testcontainers.Connection.stop_container/1","doc":":ok = Testcontainers.Connection.stop_container(\"my_container_id\")","ref":"Testcontainers.Connection.html#stop_container/1-examples"},{"type":"protocol","title":"Testcontainers.Connection.DockerHostStrategy","doc":"Defines the contract that needs to be implemented by docker host strategies","ref":"Testcontainers.Connection.DockerHostStrategy.html"},{"type":"function","title":"Testcontainers.Connection.DockerHostStrategy.execute/2","doc":"Executes the docker_host strategy","ref":"Testcontainers.Connection.DockerHostStrategy.html#execute/2"},{"type":"type","title":"Testcontainers.Connection.DockerHostStrategy.t/0","doc":"All the types that implement this protocol.","ref":"Testcontainers.Connection.DockerHostStrategy.html#t:t/0"},{"type":"module","title":"Testcontainers.Connection.DockerHostStrategy.DockerHostFromEnv","doc":"","ref":"Testcontainers.Connection.DockerHostStrategy.DockerHostFromEnv.html"},{"type":"module","title":"Testcontainers.Connection.DockerHostStrategy.DockerHostFromProperties","doc":"","ref":"Testcontainers.Connection.DockerHostStrategy.DockerHostFromProperties.html"},{"type":"module","title":"Testcontainers.Connection.DockerHostStrategy.DockerSocketPath","doc":"","ref":"Testcontainers.Connection.DockerHostStrategy.DockerSocketPath.html"},{"type":"module","title":"Testcontainers.Connection.DockerHostStrategyEvaluator","doc":"","ref":"Testcontainers.Connection.DockerHostStrategyEvaluator.html"},{"type":"function","title":"Testcontainers.Connection.DockerHostStrategyEvaluator.run_strategies/2","doc":"","ref":"Testcontainers.Connection.DockerHostStrategyEvaluator.html#run_strategies/2"},{"type":"module","title":"Testcontainers.Container","doc":"","ref":"Testcontainers.Container.html"},{"type":"function","title":"Testcontainers.Container.mapped_port/2","doc":"Gets the host port on the container for the given exposed port.","ref":"Testcontainers.Container.html#mapped_port/2"},{"type":"function","title":"Testcontainers.Container.new/2","doc":"A constructor function to make it easier to construct a container","ref":"Testcontainers.Container.html#new/2"},{"type":"function","title":"Testcontainers.Container.run/2","doc":"Starts a new container based on the provided configuration, applying any specified wait strategies.\n\nThis function performs several steps:\n1. Pulls the necessary Docker image.\n2. Creates and starts a container with the specified configuration.\n3. Registers the container with a reaper process for automatic cleanup, ensuring it is stopped and removed when the current process exits or in case of unforeseen failures.","ref":"Testcontainers.Container.html#run/2"},{"type":"function","title":"Parameters - Testcontainers.Container.run/2","doc":"- `config`: A `%Container{}` struct containing the configuration settings for the container, such as the image to use, environment variables, bound ports, and volume bindings.\n- `options`: Optional keyword list. Supports the following options:\n  - `:on_exit`: A callback function that's invoked when the current process exits. It receives a no-argument callable (often a lambda) that executes cleanup actions, such as stopping the container. This callback enhances the reaper's functionality by providing immediate cleanup actions at the process level, while the reaper ensures that containers are ultimately cleaned up in situations like abrupt process termination. It's especially valuable in test environments, complementing ExUnit's `on_exit` for resource cleanup after tests.","ref":"Testcontainers.Container.html#run/2-parameters"},{"type":"function","title":"Examples - Testcontainers.Container.run/2","doc":"iex> config = %Container{\n          image: \"mysql:latest\",\n          wait_strategies: [CommandWaitStrategy.new([\"bash\", \"sh\", \"command_that_returns_0_exit_code\"])]\n        }\n    iex> {:ok, container} = Container.run(config)","ref":"Testcontainers.Container.html#run/2-examples"},{"type":"function","title":"Returns - Testcontainers.Container.run/2","doc":"- `{:ok, container}` if the container is successfully created, started, and passes all wait strategies.\n- An error tuple, such as `{:error, reason}`, if there is a failure at any step in the process.","ref":"Testcontainers.Container.html#run/2-returns"},{"type":"function","title":"Notes - Testcontainers.Container.run/2","doc":"- The container is automatically registered with a reaper process, ensuring it is stopped and removed when the current process exits, or in the case of unforeseen failures.\n- It's important to specify appropriate wait strategies to ensure the container is fully ready for interaction, especially for containers that may take some time to start up services internally.","ref":"Testcontainers.Container.html#run/2-notes"},{"type":"function","title":"Testcontainers.Container.with_bind_mount/4","doc":"Sets a file or the directory on the _host machine_ to be mounted into a _container_.","ref":"Testcontainers.Container.html#with_bind_mount/4"},{"type":"function","title":"Testcontainers.Container.with_environment/3","doc":"Sets an _environment variable_ to the _container_.","ref":"Testcontainers.Container.html#with_environment/3"},{"type":"function","title":"Testcontainers.Container.with_exposed_port/2","doc":"Adds a _port_ to be exposed on the _container_.","ref":"Testcontainers.Container.html#with_exposed_port/2"},{"type":"function","title":"Testcontainers.Container.with_exposed_ports/2","doc":"Adds multiple _ports_ to be exposed on the _container_.","ref":"Testcontainers.Container.html#with_exposed_ports/2"},{"type":"function","title":"Testcontainers.Container.with_fixed_port/3","doc":"","ref":"Testcontainers.Container.html#with_fixed_port/3"},{"type":"function","title":"Testcontainers.Container.with_label/3","doc":"Sets a label to apply to the container object in docker.","ref":"Testcontainers.Container.html#with_label/3"},{"type":"function","title":"Testcontainers.Container.with_waiting_strategies/2","doc":"Sets multiple _waiting strategies_ for the _container_.","ref":"Testcontainers.Container.html#with_waiting_strategies/2"},{"type":"function","title":"Testcontainers.Container.with_waiting_strategy/2","doc":"Sets a _waiting strategy_ for the _container_.","ref":"Testcontainers.Container.html#with_waiting_strategy/2"},{"type":"module","title":"Testcontainers.Container.CephContainer","doc":"","ref":"Testcontainers.Container.CephContainer.html"},{"type":"function","title":"Testcontainers.Container.CephContainer.new/1","doc":"","ref":"Testcontainers.Container.CephContainer.html#new/1"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_access_key/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_access_key/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_bucket/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_bucket/2"},{"type":"function","title":"Testcontainers.Container.CephContainer.with_secret_key/2","doc":"","ref":"Testcontainers.Container.CephContainer.html#with_secret_key/2"},{"type":"module","title":"Testcontainers.Container.MySqlContainer","doc":"Functions to build and interact with MySql containers.","ref":"Testcontainers.Container.MySqlContainer.html"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.connection_parameters/2","doc":"Returns the connection parameters to connect to the database from the _host machine_.","ref":"Testcontainers.Container.MySqlContainer.html#connection_parameters/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.new/2","doc":"Builds a MySql container.\n\nUses MySql 8.0 by default, but a custom image can also be set.","ref":"Testcontainers.Container.MySqlContainer.html#new/2"},{"type":"function","title":"Options - Testcontainers.Container.MySqlContainer.new/2","doc":"- `username` sets the username for the user\n- `password` sets the password for the user\n- `database` sets the name of the database","ref":"Testcontainers.Container.MySqlContainer.html#new/2-options"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.port/1","doc":"Returns the port on the _host machine_ where the MySql container is listening.","ref":"Testcontainers.Container.MySqlContainer.html#port/1"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_database/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_database/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_password/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_password/2"},{"type":"function","title":"Testcontainers.Container.MySqlContainer.with_user/2","doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_user/2"},{"type":"module","title":"Testcontainers.Container.PostgresContainer","doc":"Functions to build and interact with PostgreSql containers.","ref":"Testcontainers.Container.PostgresContainer.html"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.connection_parameters/1","doc":"Returns the connection parameters to connect to the database from the _host machine_.","ref":"Testcontainers.Container.PostgresContainer.html#connection_parameters/1"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.new/2","doc":"Builds a PostgreSql container.\n\nUses PostgreSql 13.1 by default, but a custom image can also be set.","ref":"Testcontainers.Container.PostgresContainer.html#new/2"},{"type":"function","title":"Options - Testcontainers.Container.PostgresContainer.new/2","doc":"- `username` sets the username for the user\n- `password` sets the password for the user\n- `database` sets the name of the database","ref":"Testcontainers.Container.PostgresContainer.html#new/2-options"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.port/1","doc":"Returns the port on the _host machine_ where the MySql container is listening.","ref":"Testcontainers.Container.PostgresContainer.html#port/1"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_database/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_database/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_password/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_password/2"},{"type":"function","title":"Testcontainers.Container.PostgresContainer.with_user/2","doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_user/2"},{"type":"module","title":"Testcontainers.Container.RedisContainer","doc":"Functions to build and interact with Redis containers.","ref":"Testcontainers.Container.RedisContainer.html"},{"type":"function","title":"Testcontainers.Container.RedisContainer.connection_url/1","doc":"Returns the connection url to connect to Redis from the _host machine_.","ref":"Testcontainers.Container.RedisContainer.html#connection_url/1"},{"type":"function","title":"Testcontainers.Container.RedisContainer.new/2","doc":"Creates a Redis container.\n\nRuns Redis 6.0 by default, but a custom image can also be set.","ref":"Testcontainers.Container.RedisContainer.html#new/2"},{"type":"function","title":"Testcontainers.Container.RedisContainer.port/1","doc":"Returns the port on the _host machine_ where the Redis container is listening.","ref":"Testcontainers.Container.RedisContainer.html#port/1"},{"type":"module","title":"Testcontainers.Container.SeleniumContainer","doc":"Work in progress. Not stable for use yet.\nCan use https://github.com/stuart/elixir-webdriver for client in tests","ref":"Testcontainers.Container.SeleniumContainer.html"},{"type":"function","title":"Testcontainers.Container.SeleniumContainer.new/1","doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#new/1"},{"type":"module","title":"Testcontainers.Docker.Api","doc":"","ref":"Testcontainers.Docker.Api.html"},{"type":"function","title":"Testcontainers.Docker.Api.create_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#create_container/2"},{"type":"function","title":"Testcontainers.Docker.Api.create_exec/3","doc":"","ref":"Testcontainers.Docker.Api.html#create_exec/3"},{"type":"function","title":"Testcontainers.Docker.Api.get_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#get_container/2"},{"type":"function","title":"Testcontainers.Docker.Api.inspect_exec/2","doc":"","ref":"Testcontainers.Docker.Api.html#inspect_exec/2"},{"type":"function","title":"Testcontainers.Docker.Api.pull_image/2","doc":"","ref":"Testcontainers.Docker.Api.html#pull_image/2"},{"type":"function","title":"Testcontainers.Docker.Api.start_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#start_container/2"},{"type":"function","title":"Testcontainers.Docker.Api.start_exec/2","doc":"","ref":"Testcontainers.Docker.Api.html#start_exec/2"},{"type":"function","title":"Testcontainers.Docker.Api.stdout_logs/2","doc":"","ref":"Testcontainers.Docker.Api.html#stdout_logs/2"},{"type":"function","title":"Testcontainers.Docker.Api.stop_container/2","doc":"","ref":"Testcontainers.Docker.Api.html#stop_container/2"},{"type":"module","title":"Testcontainers.Ecto","doc":"Facilitates the creation of a Postgres container for testing with Ecto.\n\nThis module simplifies the process of launching a real Postgres database instance within a Docker container for testing purposes. It leverages the `Testcontainers` library to instantiate a Postgres container with the desired configuration, providing an isolated database environment for each test session.","ref":"Testcontainers.Ecto.html"},{"type":"macro","title":"Testcontainers.Ecto.postgres_container/1","doc":"Initiates a new Postgres instance, executes migrations, and prepares a suitable database environment, specifically tailored for testing scenarios.","ref":"Testcontainers.Ecto.html#postgres_container/1"},{"type":"macro","title":"Parameters - Testcontainers.Ecto.postgres_container/1","doc":"- `options`: Configurations for the Postgres container, provided as a keyword list. The only required option is `:app`. Other options include:\n  - `:app` - The current application's atom, necessary for building paths and other application-specific logic. This is a required parameter.\n  - `:repo` (optional) - The Ecto repository module for database interaction. If not provided, it is inferred from the `:app` option using the default naming convention (e.g., `MyApp.Repo`).\n  - `:image` (optional) - Specifies the Docker image for the Postgres container. This must be a legitimate Postgres image, with the image name beginning with \"postgres\". If omitted, the default is \"postgres:15\".\n  - `:port` (optional) - Designates the host port for the Postgres service (defaults to 5432).\n  - `:user` (optional) - Sets the username for the Postgres instance (defaults to \"postgres\").\n  - `:password` (optional) - Determines the password for the Postgres user (defaults to \"postgres\").\n  - `:database` (optional) - Specifies the name of the database to be created within the Postgres instance. If not provided, the default behavior is to create a database with the name derived from the application's atom, appended with \"_test\".\n  - `:migrations_path` (optional) - Indicates the path to the migrations folder (defaults to \"priv/repo/migrations\").","ref":"Testcontainers.Ecto.html#postgres_container/1-parameters"},{"type":"macro","title":"Database Lifecycle in Testing - Testcontainers.Ecto.postgres_container/1","doc":"It's important to note that the Postgres database initiated by this macro will remain operational for the duration of the test process and is not explicitly shut down by the macro. The database and its corresponding data are ephemeral, lasting only for the scope of the test session.\n\nAfter the tests conclude, Testcontainers will clean up by removing the database container, ensuring no residual data persists. This approach helps maintain a clean testing environment and prevents any unintended side effects on subsequent tests due to data leftovers.\n\nUsers should not rely on any manual teardown or cleanup for the database, as Testcontainers handles this aspect automatically, providing isolated, repeatable test runs.","ref":"Testcontainers.Ecto.html#postgres_container/1-database-lifecycle-in-testing"},{"type":"macro","title":"Examples - Testcontainers.Ecto.postgres_container/1","doc":"# In your application.ex file in your Phoenix project:\n\n    import Testcontainers.Ecto\n\n    @impl true\n    def start(_type, _args) do\n      postgres_container(app: :my_app),\n\n      # .. other setup code\n    end\n\n    # In mix.exs, modify the aliases to remove default Ecto setup tasks from the test alias,\n    # as they might interfere with the container-based database setup:\n\n    def aliases do\n      [\n        # ... other aliases\n\n        # Ensure the following line is NOT present, as it would conflict with the container setup:\n        # test: [\"ecto.create --quiet\", \"ecto.migrate --quiet\", \"test\"],\n      ]\n    end\n\n    # in your config/test.exs, if you want to keep appending the MIX_TEST_PARTITION env variable to the database name,\n    # you must set the database option in postgres_container macro to the same value\n\n    config :my_app, MyApp.Repo,\n      username: \"postgres\",\n      password: \"postgres\",\n      hostname: \"localhost\",\n      database: \"my_app_test\", # set this also in postgres_container macro database option, or remove the appending\n      pool: Ecto.Adapters.SQL.Sandbox,\n      pool_size: 10\n\n    # for example, to set the database name to the one above, in application.ex:\n\n    @impl true\n    def start(_type, _args) do\n      postgres_container(app: :my_app, database: \"my_app_test\"),\n\n      # .. other setup code\n    ]","ref":"Testcontainers.Ecto.html#postgres_container/1-examples"},{"type":"macro","title":"Returns - Testcontainers.Ecto.postgres_container/1","doc":"- `:ok` if the container is initiated successfully.\n- `{:error, reason}` if there is a failure in initiating the container, with `reason` explaining the cause of the failure.","ref":"Testcontainers.Ecto.html#postgres_container/1-returns"},{"type":"macro","title":"Errors - Testcontainers.Ecto.postgres_container/1","doc":"- Raises `ArgumentError` if the application is missing, not an atom, or not loaded.\n- Raises `ArgumentError` if the repo is defined and not an atom\n- Raises `ArgumentError` if the specified Docker image is not a valid Postgres image.","ref":"Testcontainers.Ecto.html#postgres_container/1-errors"},{"type":"macro","title":"Note - Testcontainers.Ecto.postgres_container/1","doc":"This utility is intended for testing environments requiring a genuine database instance. It is not suitable for production use. It mandates a valid Postgres Docker image to maintain consistent and reliable testing conditions.","ref":"Testcontainers.Ecto.html#postgres_container/1-note"},{"type":"module","title":"Testcontainers.ExUnit","doc":"Convenient macros to run containers within ExUnit tests.","ref":"Testcontainers.ExUnit.html"},{"type":"macro","title":"Testcontainers.ExUnit.container/3","doc":"Creates and manages the lifecycle of a container within ExUnit tests.\n\nWhen the `:shared` option is set to `true`, the container is created once for all tests in the module. It initializes the container before any test is run and keeps it running across multiple tests. This is useful for scenarios where the cost of setting up and tearing down the container is high, or the tests are read-only and won't change the container's state.\n\nWhen the `:shared` option is omitted or set to `false`, a new container is created for each individual test, ensuring a clean state for each test case. The container is removed after each test finishes.","ref":"Testcontainers.ExUnit.html#container/3"},{"type":"macro","title":"Parameters - Testcontainers.ExUnit.container/3","doc":"* `name`: The key that should be used to reference the container in test cases.\n  * `config`: Configuration necessary for initializing the container.\n  * `options`: Optional keyword list. Supports the following options:\n    * `:shared` - If set to `true`, the container is shared across all tests in the module. If `false` or omitted, a new container is used for each test.","ref":"Testcontainers.ExUnit.html#container/3-parameters"},{"type":"macro","title":"Examples - Testcontainers.ExUnit.container/3","doc":"To create a new container for each test:\n\n    defmodule MyTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      container :my_container, %Container{image: \"my_image\"}\n      # ...\n    end\n\nTo share a container across all tests in the module:\n\n    defmodule MySharedTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      container :my_shared_container, %Container{image: \"my_shared_image\"}, shared: true\n      # ...\n    end","ref":"Testcontainers.ExUnit.html#container/3-examples"},{"type":"macro","title":"Notes - Testcontainers.ExUnit.container/3","doc":"* The macro sets up the necessary ExUnit callbacks to manage the container's lifecycle.\n  * It ensures the `Connection` and `Reaper` are started before initializing a container.\n  * In the case of shared containers, be mindful that tests can affect the container's state, potentially leading to interdependencies between tests.","ref":"Testcontainers.ExUnit.html#container/3-notes"},{"type":"function","title":"Testcontainers.ExUnit.run_container/2","doc":"Initiates and manages the lifecycle of a Docker container within the scope of a single ExUnit test.\n\nThis function starts a new container using the provided configuration. It is designed to be used in conjunction with ExUnit's setup callbacks to facilitate the creation of a fresh, isolated environment for each test case. The container is guaranteed to terminate after the test completes, ensuring no carry-over state between tests.\n\nThe function also ensures that necessary prerequisites, such as establishing a connection and starting the reaper process, are handled. This abstraction allows test cases to focus solely on interacting with the container, confident in the knowledge that setup and teardown are managed.","ref":"Testcontainers.ExUnit.html#run_container/2"},{"type":"function","title":"Parameters - Testcontainers.ExUnit.run_container/2","doc":"* `config`: A map or keyword list that includes the configuration settings for the container. This includes settings like the image to use, network configuration, bound volumes, exposed ports, and any command or entrypoint overrides.","ref":"Testcontainers.ExUnit.html#run_container/2-parameters"},{"type":"function","title":"Examples - Testcontainers.ExUnit.run_container/2","doc":"In an ExUnit case, you might use `run_container` in a setup block:\n\n    defmodule MyContainerTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      setup do\n        # Define container configuration\n        config = %Container{image: \"my_image\", exposed_ports: [80, 443]}\n\n        # Run the container for this test\n        {:ok, container} = run_container(config)\n\n        # Pass the container info to the test\n        {:ok, container: container}\n      end\n\n      test \"example test\", %{container: container} do\n        # Your test logic here, interacting with the container as needed\n      end\n    end","ref":"Testcontainers.ExUnit.html#run_container/2-examples"},{"type":"function","title":"Notes - Testcontainers.ExUnit.run_container/2","doc":"* The container is terminated after the test completes, regardless of the test's outcome, to prevent any state from persisting that might affect subsequent tests.\n  * This function is intended for use within ExUnit test cases and might not be suitable for managing containers outside of this context.","ref":"Testcontainers.ExUnit.html#run_container/2-notes"},{"type":"module","title":"Testcontainers.Reaper","doc":"A GenServer that manages the lifecycle of the Ryuk container within the Testcontainers ecosystem.\n\nThe Reaper is responsible for ensuring that resources are cleaned up properly when test containers\nare no longer needed. It communicates with the Ryuk container, a tool used by Testcontainers to\nreap orphaned containers.","ref":"Testcontainers.Reaper.html"},{"type":"module","title":"Usage - Testcontainers.Reaper","doc":"The module is typically used in the context of integration tests where test containers are\nemployed. It starts the Ryuk container and registers filters for cleaning up resources.\n\nIt is meant to be started before interacting with any test containers and stopped after all tests\nare concluded.\n\nNote: This is an internal component and should not be used directly in tests. Instead, it's used\nby the higher-level Testcontainers APIs.","ref":"Testcontainers.Reaper.html#module-usage"},{"type":"function","title":"Testcontainers.Reaper.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Testcontainers.Reaper.html#child_spec/1"},{"type":"function","title":"Testcontainers.Reaper.label/1","doc":"Labels the container so that Ryuk can delete it.","ref":"Testcontainers.Reaper.html#label/1"},{"type":"function","title":"Testcontainers.Reaper.start_eager/1","doc":"Starts the Reaper process if it is not already running.\n\nThis function will start the Reaper unlinked (outside of the current supervision tree)\nand wait until it's registered with the local process registry.\n\nIt's particularly useful for scenarios where the Reaper needs to be started without a\nlinked supervision strategy, often before the actual test scenarios are executed.","ref":"Testcontainers.Reaper.html#start_eager/1"},{"type":"function","title":"Examples - Testcontainers.Reaper.start_eager/1","doc":"iex> Testcontainers.Reaper.start_eager()\n    {:ok, pid}","ref":"Testcontainers.Reaper.html#start_eager/1-examples"},{"type":"function","title":"Options - Testcontainers.Reaper.start_eager/1","doc":"The function accepts an optional list of options (`opts`) that are passed to the GenServer\ninitialization, though in the current implementation, these options are not used.","ref":"Testcontainers.Reaper.html#start_eager/1-options"},{"type":"function","title":"Errors - Testcontainers.Reaper.start_eager/1","doc":"If the Reaper fails to start, the function will return an error tuple.","ref":"Testcontainers.Reaper.html#start_eager/1-errors"},{"type":"function","title":"Note - Testcontainers.Reaper.start_eager/1","doc":"This function is designed to be used in setup scenarios, possibly within test suite setup\ncallbacks.","ref":"Testcontainers.Reaper.html#start_eager/1-note"},{"type":"module","title":"Testcontainers.Utils","doc":"Defines constants and functions shared across modules in `Testcontainers`.","ref":"Testcontainers.Utils.html"},{"type":"function","title":"Testcontainers.Utils.get_log_level/0","doc":"","ref":"Testcontainers.Utils.html#get_log_level/0"},{"type":"function","title":"Testcontainers.Utils.library_name/0","doc":"","ref":"Testcontainers.Utils.html#library_name/0"},{"type":"function","title":"Testcontainers.Utils.log/1","doc":"","ref":"Testcontainers.Utils.html#log/1"},{"type":"protocol","title":"Testcontainers.WaitStrategy","doc":"Defines the protocol/interface for the wait strategies in `Testcontainers`","ref":"Testcontainers.WaitStrategy.html"},{"type":"function","title":"Testcontainers.WaitStrategy.wait_until_container_is_ready/2","doc":"","ref":"Testcontainers.WaitStrategy.html#wait_until_container_is_ready/2"},{"type":"type","title":"Testcontainers.WaitStrategy.t/0","doc":"All the types that implement this protocol.","ref":"Testcontainers.WaitStrategy.html#t:t/0"},{"type":"module","title":"Testcontainers.WaitStrategy.CommandWaitStrategy","doc":"Considers container as ready as soon as a command runs successfully inside the container.","ref":"Testcontainers.WaitStrategy.CommandWaitStrategy.html"},{"type":"function","title":"Testcontainers.WaitStrategy.CommandWaitStrategy.new/3","doc":"Creates a new CommandWaitStrategy to wait until the given command executes successfully inside the container.","ref":"Testcontainers.WaitStrategy.CommandWaitStrategy.html#new/3"},{"type":"module","title":"Testcontainers.WaitStrategy.HttpWaitStrategy","doc":"Awaits a successful HTTP response from the container.","ref":"Testcontainers.WaitStrategy.HttpWaitStrategy.html"},{"type":"function","title":"Testcontainers.WaitStrategy.HttpWaitStrategy.new/6","doc":"Creates a new HttpWaitStrategy to wait until a successful HTTP response is received from the container.","ref":"Testcontainers.WaitStrategy.HttpWaitStrategy.html#new/6"},{"type":"module","title":"Testcontainers.WaitStrategy.LogWaitStrategy","doc":"Considers the container as ready as soon as a specific log message is detected in the container's log stream.","ref":"Testcontainers.WaitStrategy.LogWaitStrategy.html"},{"type":"function","title":"Testcontainers.WaitStrategy.LogWaitStrategy.new/3","doc":"Creates a new LogWaitStrategy to wait until a specific log message, matching the provided regex, appears in the container's log.","ref":"Testcontainers.WaitStrategy.LogWaitStrategy.html#new/3"},{"type":"module","title":"Testcontainers.WaitStrategy.PortWaitStrategy","doc":"Considers the container as ready when it successfully accepts connections on the specified port.","ref":"Testcontainers.WaitStrategy.PortWaitStrategy.html"},{"type":"function","title":"Testcontainers.WaitStrategy.PortWaitStrategy.new/4","doc":"Creates a new PortWaitStrategy to wait until a specified port is open and accepting connections.","ref":"Testcontainers.WaitStrategy.PortWaitStrategy.html#new/4"}],"content_type":"text/markdown"}